#!/usr/bin/python
"""Mark fix committed bugs as released."""

import sys

from optparse import OptionParser

from launchpadlib.launchpad import Launchpad


FIX_COMMITTED = u'Fix Committed'


def get_option_parser():
    """Return the option parser for this program."""
    example = "eg. %prog my-project 0.5.1"
    usage = "usage: %%prog [options] project <release|NONE> \n%s" % example
    parser = OptionParser(usage=usage)
    parser.add_option(
        "-s", "--service", dest="service",
        help="The service to use.")
    parser.add_option(
        "-t", "--tags", dest="tags",
        help="Match bugs with any of the listed tags.")
    parser.set_defaults(
        service='https://api.launchpad.net',
        tags=None)
    return parser


def close_closeable_bugtask(bug_task):
    print 'Updating bug %s [%s]' % (
        bug_task.bug.id, bug_task.bug.title)
    bug_task.status = u'Fix Released'
    bug_task.lp_save()


def main(argv=None):
    """Mark fix committed bugs as released for the users."""
    if argv is None:
        argv = sys.argv
    parser = get_option_parser()
    (options, args_) = parser.parse_args(args=argv[1:])
    if len(args_) < 2:
        # There is not a project and release.
        print parser.usage
        sys.exit(1)
    project = args_[0]
    release = args_[1]
    lp = Launchpad.login_with(
        'close_released_bugs', service_root=options.service, version='devel')
    project = lp.projects[project]
    if release == 'NONE':
        milestone = None
    else:
        milestone = project.getMilestone(name=release)
    if options.tags is not None:
        tags = options.tags.split()
    else:
        tags = None

    fixed_bug_tasks = project.searchTasks(
        status=FIX_COMMITTED, milestone=milestone,
        tags=tags)
    for bug_task in fixed_bug_tasks:
        close_closeable_bugtask(bug_task)
    return 0


if __name__ == '__main__':
    sys.exit(main())
